Struct FontFace

pub struct FontFace { /* private fields */ }
Font Face

Implementations

Source

impl FontFace

pub fn from_path<P: AsRef<Path>>( path: P, read_flags: DataAccessFlags, ) -> Result<Self>

Creates a new FontFace from a given path.

pub fn from_loader(loader: &FontLoader, face_index: u32) -> Result<Self>

Creates a new FontFace from the given FontLoader.

pub fn create_font(&self, size: f32) -> Result<Font>

Creates a new Font from this FontFace.

pub fn face_info(&self) -> &FontFaceInfo

Returns the FontFaceInfo.

pub fn face_type(&self) -> FontFaceType

Returns the FontFaceType.

pub fn face_flags(&self) -> FontFaceFlags

Returns the FontFaceFlags.

pub fn face_index(&self) -> u32

Returns a zero-based index of this font-face.

NOTE: Face index does only make sense if this face is part of a TrueType or OpenType font collection. In that case the returned value would be the index of this face in that collection. If the face is not part of a collection then the returned value would always be zero.

pub fn outline_type(&self) -> FontOutlineType

Returns the FontOutlineType.

pub fn glyph_count(&self) -> u32

Returns the number of glyphs the face provides.

pub fn diag_flags(&self) -> FontFaceDiagFlags

Returns the FontFaceDiagFlags.

pub fn face_unique_id(&self) -> u64

Returns a unique identifier describing this FontFace.

pub fn weight(&self) -> FontWeight

Returns the FontWeight.

pub fn stretch(&self) -> FontStretch

Returns the FontStretch.

pub fn style(&self) -> FontStyle

Returns the FontStyle.

pub fn data(&self) -> &FontData

Returns the FontData associated with this font-face.

pub fn loader(&self) -> &FontLoader

Returns the FontLoader associated with this font-face.

pub fn design_metrics(&self) -> &FontDesignMetrics

Returns the design metrics of this FontFace.

pub fn units_per_em(&self) -> i32

Returns the units per em, which are part of font’s design metrics.

pub fn unicode_coverage(&self) -> &FontUnicodeCoverage

pub fn full_name(&self) -> &str

Returns the full name.

pub fn family_name(&self) -> &str

Returns the family name.

pub fn subfamily_name(&self) -> &str

Returns the subfamily name.

pub fn post_script_name(&self) -> &str

Returns the post script name.