pub struct FontFaceFlags { /* private fields */ }Implementations
Sourceimpl FontFaceFlags
impl FontFaceFlags
pub const TYPOGRAPHIC_NAMES: FontFaceFlags
pub const TYPOGRAPHIC_METRICS: FontFaceFlags
pub const CHAR_TO_GLYPH_MAPPING: FontFaceFlags
pub const HORIZONTAL_METIRCS: FontFaceFlags
pub const VERTICAL_METRICS: FontFaceFlags
pub const HORIZONTAL_KERNING: FontFaceFlags
pub const VERTICAL_KERNING: FontFaceFlags
pub const OPENTYPE_FEATURES: FontFaceFlags
pub const OPENTYPE_VARIATIONS: FontFaceFlags
pub const PANOSE_DATA: FontFaceFlags
pub const UNICODE_COVERAGE: FontFaceFlags
pub const VARIATION_SEQUENCES: FontFaceFlags
pub const SYMBOL_FONT: FontFaceFlags
pub const LAST_RESORT_FONT: FontFaceFlags
Sourcepub fn empty() -> FontFaceFlags
pub fn empty() -> FontFaceFlags
Returns an empty set of flags.
Sourcepub fn all() -> FontFaceFlags
pub fn all() -> FontFaceFlags
Returns the set containing all flags.
Sourcepub fn from_bits(bits: u32) -> Option<FontFaceFlags>
pub fn from_bits(bits: u32) -> Option<FontFaceFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub fn from_bits_truncate(bits: u32) -> FontFaceFlags
pub fn from_bits_truncate(bits: u32) -> FontFaceFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub fn intersects(&self, other: FontFaceFlags) -> bool
pub fn intersects(&self, other: FontFaceFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub fn contains(&self, other: FontFaceFlags) -> bool
pub fn contains(&self, other: FontFaceFlags) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: FontFaceFlags)
pub fn insert(&mut self, other: FontFaceFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: FontFaceFlags)
pub fn remove(&mut self, other: FontFaceFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: FontFaceFlags)
pub fn toggle(&mut self, other: FontFaceFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: FontFaceFlags, value: bool)
pub fn set(&mut self, other: FontFaceFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.