Struct GlyphBuffer

pub struct GlyphBuffer { /* private fields */ }
Glyph buffer.

Can hold either text or glyphs and provides basic memory management that is used for text shaping, character to glyph mapping, glyph substitution, and glyph positioning.

Glyph buffer provides two separate buffers called ‘primary’ and ‘secondary’ that serve different purposes during processing. Primary buffer always hold a GlyphItem array, and secondary buffer is either used as a scratch buffer during glyph substitution or hold glyph positions after the processing is complete and glyph positions were calculated.

Implementations

Source

impl GlyphBuffer

pub fn new() -> Self

Creates a new empty GlyphBuffer.

pub fn from_utf8_text(text: &str) -> Self

Creates a new GlyphBuffer initialized with the given text.

pub fn glyph_run(&self) -> GlyphRun<'_>

pub fn glyph_item_data(&self) -> GlyphRun<'_>

pub fn size(&self) -> usize

pub fn flags(&self) -> GlyphRunFlags

Returns the GlyphBuffer’s GlyphRunFlags.

pub fn has_text(&self) -> bool

Returns true if this GlyphBuffer contains unicode data.

pub fn has_glyphs(&self) -> bool

Returns true if this GlyphBuffer contains GlyphId data.

pub fn has_invalid_chars(&self) -> bool

Returns true if this GlyphBuffer contains invalid characters(unicode encoding errors).

pub fn has_undefined_chars(&self) -> bool

Returns true if this GlyphBuffer contains undefined characters that weren’t mapped properly to glyphs.

pub fn has_invalid_font_data(&self) -> bool

Returns true if one or more operations were terminated before completion because of invalid data in a font.

pub fn clear(&mut self)

Clears the content of this GlyphBuffer without releasing internal buffers.

pub fn set_utf8_text(&mut self, text: &str)

Sets text content of this GlyphBuffer.