#[repr(C)]pub struct BuildInfo {
pub version: u32,
pub build_type: BuildType,
pub baseline_cpu_features: CpuFeatures,
pub supported_cpu_features: CpuFeatures,
pub max_image_size: u32,
pub max_thread_count: u32,
/* private fields */
}Expand description
Blend2D build information.
Fields
version: u32Blend2D version stored as ((MAJOR << 16) | (MINOR << 8) | PATCH).
build_type: BuildTypeBlend2D build type, see BuildType.
baseline_cpu_features: CpuFeaturesBaseline CPU features, see CpuFeatures.
These features describe CPU features that were detected at compile-time. Baseline features are used to compile all source files so they represent the minimum feature-set the target CPU must support to run Blend2D.
Official Blend2D builds set baseline at SSE2 on X86 target and NEON on
ARM target. Custom builds can set use different baseline, which can be
read through BLRuntimeBuildInfo.
supported_cpu_features: CpuFeaturesSupported CPU features, see CpuFeatures.
These features do not represent the features that the host CPU must support,
instead, they represent all features that Blend2D can take advantage of in
C++ code that uses instruction intrinsics. For example if AVX2 is part of
supportedCpuFeatures it means that Blend2D can take advantage of it if
there is a separate code-path.
max_image_size: u32Maximum size of an image (both width and height).
max_thread_count: u32Maximum number of threads for asynchronous operations, including rendering.